/* (C) 2021 YiRing, Inc. */
package com.yiring.common.aspect;

import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.stereotype.Component;

/**
 * XxlJob 注解切面，修复无法输出异常的问题
 *
 * @author ifzm
 * @version 0.1
 */

@Slf4j
@Aspect
@Component
@ConditionalOnClass(name = "com.xxl.job.core.handler.annotation.XxlJob")
public class XxlJobAspect {

    @Pointcut("@annotation(com.xxl.job.core.handler.annotation.XxlJob)")
    public void log() {}

    @Around("log()")
    public Object around(ProceedingJoinPoint point) throws Throwable {
        try {
            return point.proceed();
        } catch (Exception e) {
            log.error("XxlJob Execute Error: " + e.getMessage(), e);
            throw e;
        }
    }
}
